@@ -1,16 +1,66 @@
 use 5.14.0;
-package Router::Dumb;
-{
-  $Router::Dumb::VERSION = '0.005';
-}
+package Router::Dumb 0.006;
 use Moose;
 # ABSTRACT: yet another dumb path router for URLs
 
+#pod =head1 SYNOPSIS
+#pod
+#pod   my $r = Router::Dumb->new;
+#pod
+#pod   $r->add_route(
+#pod     Router::Dumb::Route->new({
+#pod       parts       => [ qw(group :group uid :uid) ],
+#pod       target      => 'pants',
+#pod       constraints => {
+#pod         group => find_type_constraint('Int'),
+#pod       },
+#pod     }),
+#pod   );
+#pod
+#pod   my $match = $r->route( '/group/123/uid/321' );
+#pod   
+#pod   # $match->target  returns 'pants'
+#pod   # $match->matches returns (group => 123, uid => 321)
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod Router::Dumb provides a pretty dumb router.  You can add routes and then ask
+#pod how to route a given path string.
+#pod
+#pod Routes have a path.  A path is an arrayref of names.  Names that start with a
+#pod colon are placeholders.  Everything else is a literal.  Literals pieces must
+#pod appear, literally, in the string being routed.  A placeholder can be satisfied
+#pod by any value, as long as it satisfies the placeholder's constraint.  If there's
+#pod no constraint, any value works.
+#pod
+#pod The special part C<*> can be used to mean "...then capture everything else into
+#pod the placeholder named C<REST>."
+#pod
+#pod Most of the time, you won't be calling C<add_route>, but using some other
+#pod helper to figure out routes to add for you.  Router::Dumb ships with
+#pod L<Router::Dumb::Helper::FileMapper> and L<Router::Dumb::Helper::RouteFile>.
+#pod
+#pod =cut
 
 use Router::Dumb::Route;
 
 use namespace::autoclean;
 
+#pod =method add_route
+#pod
+#pod   $router->add_route(
+#pod     Router::Dumb::Route->new({
+#pod       parts  => [ qw( the :path parts ) ],
+#pod       target => 'target-string',
+#pod       constraints => {
+#pod         path => $moose_tc,
+#pod       },
+#pod     })
+#pod   );
+#pod
+#pod This method adds a new L<route|Router::Dumb::Route> to the router.
+#pod
+#pod =cut
 
 sub add_route {
   my ($self, $route) = @_;
@@ -29,6 +79,20 @@ sub add_route {
   $self->_add_route($npath, $route);
 }
 
+#pod =method add_route_unless_exists
+#pod
+#pod   $router->add_route_unless_exists(
+#pod     Router::Dumb::Route->new({
+#pod       parts  => [ qw( the :path parts ) ],
+#pod       target => 'target-string',
+#pod       ...
+#pod     })
+#pod   );
+#pod
+#pod This method adds a new L<route|Router::Dumb::Route> to the router unless it
+#pod would conflict, in which case it does nothing.
+#pod
+#pod =cut
 
 sub add_route_unless_exists {
   my ($self, $route) = @_;
@@ -41,6 +105,16 @@ sub add_route_unless_exists {
   $self->_add_route($npath, $route);
 }
 
+#pod =method route
+#pod
+#pod   my $match_or_undef = $router->route( $str );
+#pod
+#pod If the given string can be routed to a match, the L<match|Router::Dumb::Match>
+#pod is returned.  If not, the method returns false.
+#pod
+#pod The string must begin with a C</>.
+#pod
+#pod =cut
 
 sub route {
   my ($self, $str) = @_;
@@ -91,6 +165,15 @@ has _route_map => (
   },
 );
 
+#pod =method ordered_routes
+#pod
+#pod   my @routes = $router->ordered_routes;
+#pod
+#pod This method returns the router's routes, in the order that they will be
+#pod checked.  You probably do not want to use this method unless you really know
+#pod what you're doing.
+#pod
+#pod =cut
 
 sub ordered_routes {
   my ($self, $filter) = @_;
@@ -107,13 +190,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Router::Dumb - yet another dumb path router for URLs
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
@@ -152,6 +237,16 @@ Most of the time, you won't be calling C<add_route>, but using some other
 helper to figure out routes to add for you.  Router::Dumb ships with
 L<Router::Dumb::Helper::FileMapper> and L<Router::Dumb::Helper::RouteFile>.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 METHODS
 
 =head2 add_route
@@ -200,11 +295,27 @@ what you're doing.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
+
+=head1 CONTRIBUTORS
+
+=for stopwords Karen Etheridge Ricardo Signes
+
+=over 4
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Ricardo Signes <rjbs@semiotic.systems>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo Signes.
+This software is copyright (c) 2022 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
