@@ -1,11 +1,28 @@
 use 5.14.0;
-package Router::Dumb::Helper::RouteFile;
-{
-  $Router::Dumb::Helper::RouteFile::VERSION = '0.005';
-}
+package Router::Dumb::Helper::RouteFile 0.006;
 use Moose;
 # ABSTRACT: something to read routes out of a dumb text file
 
+#pod =head1 OVERVIEW
+#pod
+#pod   my $r = Router::Dumb->new;
+#pod   
+#pod   Router::Dumb::Helper::RouteFile->new({ filename => 'routes.txt' })
+#pod                                  ->add_routes_to( $r );
+#pod
+#pod ...and F<routes.txt> looks like...
+#pod
+#pod   # These are some great routes!
+#pod
+#pod   /citizen/:num/dob  =>  /citizen/dob
+#pod     num isa Int
+#pod
+#pod   /blog/*            =>  /blog
+#pod
+#pod Then routes are added, doing just what you'd expect.  This helper is pretty
+#pod dumb, but the whole Router::Dumb system is, too.
+#pod
+#pod =cut
 
 use Router::Dumb::Route;
 
@@ -68,13 +85,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Router::Dumb::Helper::RouteFile - something to read routes out of a dumb text file
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 OVERVIEW
 
@@ -95,13 +114,23 @@ version 0.005
 Then routes are added, doing just what you'd expect.  This helper is pretty
 dumb, but the whole Router::Dumb system is, too.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo Signes.
+This software is copyright (c) 2022 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
